<?php

// Element Description: PT Blog

class PT_Blog_Items extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_blog_mapping' ) );
        add_shortcode( 'pt_blog', array( $this, 'pt_blog_html' ) );
    }
     
    // Element Mapping
    public function pt_blog_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Blog", "imate"),
            "base" => "pt_blog",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-blog",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Count items", "imate" ),
                    "param_name"  => "count_items",
                    "value"       => '9',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "imate" ),
                    "param_name"  => "type",
                    "value"      => array(
                        esc_html__( "Grid", "imate" ) => "grid",
                        esc_html__( "Masonry", "imate" ) => "masonry",
                        esc_html__( "Horizontal", "imate" ) => "horizontal",
                    ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Carousel mode", "imate" ),
                    "param_name"  => "carousel_mode",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => false,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums", "imate" ),
                    "param_name"  => "cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                    "dependency"  => Array( "element" => "type", "value" => array( "grid", "masonry" ) ),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Short Description Size", "imate" ),
                    "param_name"  => "short_desc_size",
                    "description" => esc_html__( "(option)", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Filter buttons", "imate" ),
                    "param_name"  => "filter_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Filter buttons align", "imate" ),
                    "param_name"  => "filter_buttons_align",
                    "value"      => array(
                        esc_html__('Left', 'imate') => 'tal',
                        esc_html__('Center', 'imate') => 'tac',
                        esc_html__('Right', 'imate') => 'tar',
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Navigation", "imate" ),
                    "param_name"  => "navigation",
                    "value"      => array(
                        esc_html__( "None", "imate" ) => "none",
                        esc_html__( "Load More", "imate" ) => "load_more",
                        esc_html__( "Pagination", "imate" ) => "pagination",
                    ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Navigation buttons", "imate" ),
                    "param_name"  => "nav_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Autoplay", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => false,
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Autoplay timeout", "imate" ),
                    "param_name"  => "autoplay_timeout",
                    "value"       => '5000',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on desktop", "imate" ),
                    "param_name"  => "cols_on_desktop",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '4',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on tablet", "imate" ),
                    "param_name"  => "cols_on_tablet",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums on mobile", "imate" ),
                    "param_name"  => "cols_on_mobile",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '2',
                    "dependency"  => Array( "element" => "carousel_mode", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel settings", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Image", "imate" ),
                    "param_name"  => "show_image",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Date", "imate" ),
                    "param_name"  => "show_date",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Heading", "imate" ),
                    "param_name"  => "show_heading",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "show_category",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Read More", "imate" ),
                    "param_name"  => "show_readmore",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Likes", "imate" ),
                    "param_name"  => "show_likes",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order by", "imate" ),
                    "param_name"  => "orderby",
                    "value"      => array(
                        esc_html__('Default', 'imate') => 'post__in',
                        esc_html__('Author', 'imate') => 'author',
                        esc_html__('Date', 'imate') => 'date',
                        esc_html__('ID', 'imate') => 'ID',
                        esc_html__('Title', 'imate') => 'title',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order", "imate" ),
                    "param_name"  => "order",
                    "value"      => array(
                        esc_html__('Ascending order', 'imate') => 'ASC',
                        esc_html__('Descending order', 'imate') => 'DESC',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "imate" ),
                    "param_name"  => "source",
                    "value"      => array(
                        esc_html__( "---", "imate" ) => "",
                        esc_html__( "Items", "imate" ) => "items",
                        esc_html__( "Categories", "imate" ) => "categories",
                    ),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "imate" ),
                    "param_name"  => "items",
                    "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                    "value"       => get_all_blog_items(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories",
                    "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                    "value"       => get_all_blog_category(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_blog_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'count_items' => '9', 
                    'type' => 'grid',
                    'cols' => '3',
                    'short_desc_size' => '',
                    'filter_buttons' => 'on',
                    'filter_buttons_align' => 'tal',
                    'navigation' => 'none',
                    'show_image' => 'on',
                    'show_date' => 'on',
                    'show_category' => 'on',
					'show_heading' => 'on',
                    'show_desc' => 'on',
                    'show_readmore' => 'on',
                    'show_likes' => 'on',
                    'orderby' => 'post__in',
                    'order' => 'ASC',
                    'source' => '',
                    'items' => '',
                    'categories' => '',
                    'source' => '',
                    'carousel_mode' => 'off',
                    'nav_buttons' => 'on',
                    'autoplay' => 'off',
                    'autoplay_timeout' => '5000',
                    'cols_on_desktop' => '4',
                    'cols_on_tablet' => '3',
                    'cols_on_mobile' => '2',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $wrap_id = 'blog-'.$uniq_id;

        $animation = $this->getCSSAnimation($animation);

        if(is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        $tax_query = array();

        $categories_s = '';
        if ( !empty($categories) && $categories != '0' ) {
            $categories_s = explode(',', $categories);
            $tax_query = array(
                array(
                    'taxonomy' => 'category',
                    'field'    => 'id',
                    'terms'    => $categories_s
                )
            );
        }
        if($items) {
            $items = explode(',', $items);
        } else {
            $items = '';
        }
        $args = array(
            'post__in'        => $items,
            'posts_per_page'  => $count_items,
            'paged'           => $paged,
            'orderby'         => $orderby,
            'order'           => $order,
            'post_type'       => 'post',
            'post_status'     => 'publish',
            'tax_query'       => $tax_query
        );

        $blog_array = new WP_Query( $args );

        $max_num_pages = 0;
        $max_num_pages = $blog_array->max_num_pages;

        $html = '';

        if($type != 'standart') {
            switch ($cols) {
                case '1':
                    $item_col = "col-xs-12";
                    break;
                case '2':
                    $item_col = "col-xs-12 col-sm-6";
                    break;
                case '3':
                    $item_col = "col-xs-12 col-sm-4";
                    break;
                case '4':
                    $item_col = "col-xs-12 col-sm-4 col-md-3";
                    break;
                
                default:
                    $item_col = "";
                    break;
            }
        } else {
            switch ($cols) {
                case '1':
                    $item_col = "col-xs-12";
                    break;
                case '2':
                    $item_col = "col-xs-12 col-md-6";
                    break;
                case '3':
                    $item_col = "col-xs-12 col-md-4";
                    break;
                case '4':
                    $item_col = "col-xs-12 col-md-6 col-lg-3";
                    break;
                
                default:
                    $item_col = "";
                    break;
            }
        }

        $item_num = 0;

        $category_array = array();
        if($items) {
            $i = 0;
            while ( $blog_array->have_posts() ) : $blog_array->the_post();
                $id = get_the_ID();
                $category_array[$i] = array();
                foreach (wp_get_post_terms( $id, 'category') as $key2 => $s_item) {
                    $category_array[$i][$key2] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
                $i++;
            endwhile;

            $arrOut = array();
            foreach($category_array as $subArr){
                $arrOut = array_merge($arrOut,$subArr);
            }

            $category_array = array_map( 'unserialize', array_unique( array_map( 'serialize', $arrOut)));
        } else if(is_array($categories_s) && count($categories_s) > 0) {
            $args     = array(
                'hide_empty' => true,
                'include' => $categories_s
            );
            $taxonomy = 'category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms) && !is_wp_error( $terms )) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        } else {
            $args     = array(
                'hide_empty' => true,
            );
            $taxonomy = 'category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms)) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        }

        $html = $wrap_classes = "";

        if(isset($carousel_mode) && $carousel_mode == "on") {
            $filter_buttons = "off";
            $item_col = '';
            
            if($nav_buttons == 'on') {
                $arrows = 'true';
            } else {
                $arrows = 'false';
            }

            if($autoplay == 'on') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }

            $wrap_classes .= ' disable-iso';

            $navigation = 'disable';

            wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
            wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
            wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
                jQuery('.".esc_attr($wrap_id)."').each(function(){
                    var head_slider = jQuery(this);
                    if(jQuery(this).find('.blog-item').length > 1){
                        head_slider.addClass('owl-carousel').owlCarousel({
                            loop:true,
                            items:1,
                            nav: ".esc_js($arrows).",
                            dots: false,
                            autoplay: ".esc_js($autoplay).",
                            autoplayTimeout: ".esc_js($autoplay_timeout).",
                            autoplayHoverPause: true,
                            navClass: ['owl-prev fa fa-angle-left','owl-next fa fa-angle-right'],
                            navText: false,
                            margin: 30,
                            responsive:{
                                0:{
                                    nav: false,
                                    items: 1
                                },
                                768:{
                                    nav: ".esc_js($arrows).",
                                    items: ".esc_js($cols_on_mobile)."
                                },
                                992:{
                                    items: ".esc_js($cols_on_tablet)."
                                },
                                1200:{
                                    items: ".esc_js($cols_on_desktop)."
                                },
                            },
                        });
                    }
                });
            });");
        }

        if(is_array($blog_array->posts) && count($blog_array->posts) > 0) {
            if(is_array($category_array) && $filter_buttons == "on" && count($category_array) > 1) {
                $html .= '<div class="filter-button-group '.esc_attr($filter_buttons_align).'">';
                    $html .= '<div class="wrap">';
                        $html .= '<button data-filter="*" class="active">'.esc_html__('All', 'imate').'</button>';
                        foreach($category_array as $item) { 
                            $name = $item["name"];
                            $slug = $item["slug"];
                            $html .= '<button data-filter=".category-'.esc_attr($slug).'">'.esc_html($name).'</button>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            }
            $html .= '<div class="blog-items row blog-type-'.$type.' '.$wrap_id.' '.$wrap_classes.'">';
                while ( $blog_array->have_posts() ) : $blog_array->the_post();
                    $id = get_the_ID();
                    $item = get_post($id);
                    $item_num++;
                    $name = $item->post_title;
                    $item_class = $category = $category_links_html = $quote = "";
                    if(is_array(wp_get_post_terms( $id, 'category'))) {
                        for ($i=0; $i < count(wp_get_post_terms( $id, 'category')); $i++) {
                            $category_links_html .= '<a href="'.esc_url(get_category_link(wp_get_post_terms( $id, 'category')[$i]->term_id)).'">'.esc_html(wp_get_post_terms( $id, 'category')[$i]->name).'</a>, ';
                            $category .= wp_get_post_terms( $id, 'category')[$i]->name.', ';
                            $item_class .= 'category-'.wp_get_post_terms( $id, 'category')[$i]->slug.' ';
                        }
                    }

                    $backup_type = $type;
                    $backup_show_desc = $show_desc;
                    $backup_show_image = $show_image;
                    
                    $item_class = trim($item_class, ' ');
                    $category = trim($category, ', ');
                    $category_links_html = trim($category_links_html, ', ');
                    $thumb = get_post_meta( $id, '_thumbnail_id', true );
                    $image = wp_get_attachment_image_src( $thumb , 'full' );

                    if($show_desc == 'on') {
                        if(function_exists('get_field') && get_field('short_desc')) {
                            $desc = get_field('short_desc', $id);
                        } else {
                            $desc = strip_tags(strip_shortcodes($item->post_content));
                        }
                    } else {
                        $desc = "";
                    }

                    if(function_exists('get_field')) {
                        if(get_field('post_grid_short_desc', $id) == 'no' && $carousel_mode != "on") {
                            $show_desc = 'off';
                        }
                        if(($type != 'horizontal' && $carousel_mode != 'on') && get_field('post_type', $id) == 'quote') {
                            $type = get_field('post_type', $id);
                            $item_class .= ' type-quote';
                            $show_desc = 'on';
                            $desc = strip_tags(get_field('post_quote', $id));
                        }
                        if(get_field('post_grid_featured_image', $id) == 'no' && $carousel_mode != "on") {
                            $show_image = 'off';
                        }
                    }

                    if(!empty($short_desc_size)) {
                        $count = $short_desc_size;
                    } else if(is_page_template('template-with-sidebar.php') && ($type == 'grid' || $type == 'horizontal' || $type == 'masonry')) {
                        $count = '155';
                    } else if($type == 'grid' || $type == 'masonry') {
                        $count = '155';
                    } else if($type == 'horizontal') {
                        $count = '480';
                    } else if($type == 'quote') {
                        $count = '90';
                    }

                    if($type == 'horizontal') {
                        $item_col = '';
                    }

                    if($desc && $show_desc == 'on') {
                        if(function_exists('iconv_strlen') && iconv_strlen($desc, 'UTF-8') > $count) {
                            $desc = mb_substr($desc, 0, $count).'...';
                        } else if(!function_exists('iconv_strlen')) {
                            $desc = mb_substr($desc, 0, $count);
                        }
                    }

                    if(isset($image[0]) && !empty($image[0]) && $show_image == 'on') {
                    	$item_class .= ' with-image';
                    }

                    $html .= '<article class="blog-item '.esc_attr($item_class.' '.$item_col).'">';
                    	$html .= '<div class="wrap '.esc_attr($animation).'">';
                            if($type != 'quote') {
                                if($show_image == 'on' && isset($image[0]) && !empty($image[0])) {
                                    if($type == 'masonry') {
                                        $html .= '<div class="img"><a href="'.esc_url(get_permalink($id)).'"><img width="'.esc_attr($image[1]).'" height="'.esc_attr($image[2]).'" src="'.esc_url($image[0]).'" alt="'.esc_html($name).'"></a></div>';
                                    } else {
                                        $html .= '<div class="img"><a href="'.esc_url(get_permalink($id)).'" style="background-image: url('.esc_url($image[0]).');"></a></div>';
                                    }
                                }
                                $html .= '<div class="content">';
                                    if($show_heading == 'on') {
                                        $html .= '<h6><a href="'.esc_url(get_permalink($id)).'">'.esc_html($name).'</a></h6>';
                                    }
                                    if($show_date == 'on' || ($show_category == 'on' && !empty($category))) {
                                        $html .= '<div class="blog-detail">';
                                            if($show_date == 'on') {
                                                $html .= '<div class="bd-item"><i class="material-design-icon-history-clock-button"></i><span>'.get_the_date('', $id).'</span></div>';
                                            }
                                            if($show_category == 'on' && !empty($category)) {
                                                $html .= '<div class="bd-item"><i class="material-design-icon-label-right-arrow-outline"></i><span>'.strip_tags($category).'</span></div>';
                                            }
                                        $html .= '</div>';
                                    }
                                    if($show_desc == 'on') {
                                        $html .= '<div class="text">'.wp_kses_post($desc).'</div>';
                                    }
                                    if($show_readmore == 'on') {
                                        $html .= '<a href="'.get_permalink($id).'" class="readmore-link"><span>'.esc_html__('Read More', 'imate').'</span><i class="fa fa-angle-right"></i></a>';
                                    }
                                    if($show_likes == 'on' && function_exists('zilla_likes')) {
                                        $html .= zilla_likes($id);
                                    }
                                $html .= '</div>';
                            } else {
                                if($show_date == 'on') {
                                    $html .= '<div class="blog-detail">';
                                        $html .= '<div class="bd-item"><span>'.get_the_date('', $id).'</span></div>';
                                    $html .= '</div>';
                                }
                                if(!empty($desc)) {
                                    $html .= '<div class="quote">'.strip_tags($desc).'</div>';
                                }
                                $html .= '<div class="author">';
                                    if(($avatar = get_avatar(get_the_author_meta('ID'), '300')) !== FALSE) {
                                        preg_match_all( '/(alt|title|src)=("[^"]*")/i' , $avatar, $match );
                                        $url = str_replace('"', '', $match[2][0]);
                                        $html .= '<div class="image" style="background-image: url('.esc_url($url).')"></div>';
                                    }
                                    $html .= '<div class="cell">'.get_the_author_meta('display_name').'</div>';
                                $html .= '</div>';
                                $html .= '<a href="'.get_permalink($id).'"></a>';
                            }
                        $html .= '</div>';
                    $html .= '</article>';

                    $type = $backup_type;
                    $show_desc = $backup_show_desc;
                    $show_image = $backup_show_image;

                endwhile;
                wp_reset_postdata();
            $html .= '</div>';
        }

        if($navigation == "pagination") {
            if (function_exists('imate_wp_corenavi')) {
                $html .= imate_wp_corenavi($max_num_pages);
            } else {
                $html .= wp_link_pages();
            };
        }
        if(is_array($blog_array->posts) && $navigation == "load_more" && $max_num_pages > 1) {
            $html .= '<div class="load-button tac"><a href="#" data-wrap=".'.esc_attr($wrap_id).'" data-max="'.esc_attr($max_num_pages).'" data-start-page="'.esc_attr($paged).'" data-next-link="'.esc_url(next_posts($max_num_pages, false)).'" class="button-style3 gray"><span>'.esc_html('Load more', 'imate').'</span></a></div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Blog_Items();