<?php

// Element Description: PT Button

class PT_Button extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_button_mapping' ) );
        add_shortcode( 'pt_button', array( $this, 'pt_button_html' ) );
    }
     
    // Element Mapping
    public function pt_button_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Button", "imate"),
            "base" => "pt_button",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-button",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Button Style", "imate" ),
                    "param_name"  => "style",
                    "value"      => array(
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                    ),
                    "admin_label" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Button align", "imate" ),
                    "param_name"  => "align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                ),
                array(
                    "type"        => "vc_link",
                    "heading"     => esc_html__( "Link", "imate" ),
                    "param_name"  => "link",
                    "admin_label" => true,
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Link with icon", "imate" ),
                    "param_name"  => "link_w_icon",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => false,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Icon position", "imate" ),
                    "param_name"  => "link_icon_position",
                    "value"      => array(
                        esc_html__( "Before", "imate" ) => "before",
                        esc_html__( "After", "imate" ) => "after",
                    ),
                    "dependency" => Array("element" => "link_w_icon", "value" => "on" ),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__( 'Icon library', 'imate' ),
                    'value' => array(
                        esc_html__( 'Font Awesome', 'imate' ) => 'fontawesome',
                        esc_html__( 'Open Iconic', 'imate' ) => 'openiconic',
                        esc_html__( 'Typicons', 'imate' ) => 'typicons',
                        esc_html__( 'Entypo', 'imate' ) => 'entypo',
                        esc_html__( 'Linecons', 'imate' ) => 'linecons',
                        esc_html__( 'Mono Social', 'imate' ) => 'monosocial',
                        esc_html__( 'Material', 'imate' ) => 'material',
                    ),
                    "dependency" => Array("element" => "link_w_icon", "value" => "on" ),
                    'param_name' => 'type',
                    'description' => esc_html__( 'Select icon library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_fontawesome',
                    'value' => 'fa fa-adjust',
                    'settings' => array(
                        'emptyIcon' => false,
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'fontawesome',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_openiconic',
                    'value' => 'vc-oi vc-oi-dial',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'openiconic',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'openiconic',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_typicons',
                    'value' => 'typcn typcn-adjust-brightness',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'typicons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'typicons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_entypo',
                    'value' => 'entypo-icon entypo-icon-note',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'entypo',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'entypo',
                    ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_linecons',
                    'value' => 'vc_li vc_li-heart',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'linecons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'linecons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_monosocial',
                    'value' => 'vc-mono vc-mono-fivehundredpx',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'monosocial',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'monosocial',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_material',
                    'value' => 'vc-material vc-material-cake',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'material',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'material',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_button_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'style' => 'style1',
                    'align' => 'tal',
                    'link' => '',
                    'link_w_icon' => 'off',
                    'link_icon_position' => 'before',
                    'type' => 'fontawesome',
                    'icon_fontawesome' => 'fa fa-adjust',
                    'icon_openiconic' => 'vc-oi vc-oi-dial',
                    'icon_typicons' => 'typcn typcn-adjust-brightness',
                    'icon_entypo' => 'entypo-icon entypo-icon-note',
                    'icon_linecons' => 'vc_li vc_li-heart',
                    'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
                    'icon_material' => 'vc-material vc-material-cake',
                    'css' => '',
                    'animation' => '',
                ), 
                $atts
            )
        );

        $html = $item_class = '';

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        if(!empty($align)) {
            $item_class .= ' '.$align;
        }

        $link = vc_build_link($link);

        if(isset($link['target']) && empty($link['target'])) {
            $link['target'] = '_self';
        }

        if(isset($link['title']) && empty($link['title'])) {
            $link['title'] = esc_html__('read more', 'imate');
        }

        if(isset($link['url']) && !empty($link['url'])) {
            if($link_w_icon == 'on') {
                $icon = 'icon_'.$type;
                $style .= ' button-with-icon';
            }

            $html = '<div class="button-container'.esc_attr($item_class).'">';
                $html .= '<a href="'.esc_url($link['url']).'" class="button-'.esc_attr($style).'" title="'.esc_attr($link['title']).'" target="'.esc_attr($link['target']).'">';
                    if($link_w_icon == 'on' && $link_icon_position == 'before') {
                        $html .= '<i class="'.esc_attr($$icon).'"></i>';
                    }
                    $html .= '<span>'.strip_tags($link['title']).'</span>';
                    if($link_w_icon == 'on' && $link_icon_position == 'after') {
                        $html .= '<i class="'.esc_attr($$icon).'"></i>';
                    }
                $html .= '</a>';
            $html .= '</div>';
        }

        return $html;
         
    }

} // End Element Class
 

// Element Class Init
new PT_Button();