<?php

// Element Description: PT Product
if(class_exists( 'WooCommerce' )) {
    class PT_Product_Items extends WPBakeryShortCode {
         
        // Element Init
        function __construct() {
            add_action( 'init', array( $this, 'pt_product_mapping' ) );
            add_shortcode( 'pt_product', array( $this, 'pt_product_html' ) );
        }

        public static function get_all_product_category() {
            $taxonomy = 'product_cat';
            $args     = array(
                'hide_empty' => true,
            );

            $terms     = get_terms( $taxonomy, $args );
            $result    = array();
            $result[0] = "";

            if ( ! empty( $terms ) && !is_wp_error( $terms ) ) {
                foreach ( $terms as $term ) {
                    $name = get_category_parents($term->term_id);
                    if(empty($name)) {
                        $name = $term->name;
                    }
                    $name = trim($name, '/');
                    $result[ 'ID ['.$term->term_id.'] '.$name ] = $term->slug;
                }
            }

            return $result;
        }

        public static function get_all_product_items( $param = 'All' ) {
            $result    = array();
            
            $args = array(
                'post_type'       => 'product',
                'post_status'     => 'publish',
                'posts_per_page'    => '10000'
            );

            $porfolio_array = new WP_Query( $args );
            $result[0] = "";

            if ( ! empty( $porfolio_array->posts ) ) {
                foreach ( $porfolio_array->posts as $item ) {
                    $result[ 'ID ['.$item->ID.'] '. $item->post_title ] = $item->ID;
                }
            }

            return $result;
        }
         
        // Element Mapping
        public function pt_product_mapping() {
             
            // Stop all if VC is not enabled
            if ( !defined( 'WPB_VC_VERSION' ) ) {
                return;
            }
             
            // Map the block with vc_map()
            vc_map( array(
                "name" => esc_html__("Product", "imate"),
                "base" => "pt_product",
                "show_settings_on_create" => true,
                "icon" => "shortcode-icon-product",
                "is_container" => true,
                "category" => esc_html__("By PT", "imate"),
                "params" => array(
                    array(
                        "type"        => "textfield",
                        "heading"     => esc_html__( "Uniq ID", "imate" ),
                        "param_name"  => "uniq_id",
                        "value"       => uniqid(),
                    ),
                    array(
                        "type"        => "switch",
                        "heading"     => esc_html__( "Carousel", "imate" ),
                        "param_name"  => "carousel",
                        "value"       => "off",
                        "options"     => array(
                            "on" => array(
                                "on"    => "Yes",
                                "off"   => "No",
                            ),
                        ),
                        "default_set" => false,
                    ),
                    array(
                        "type"        => "number",
                        "heading"     => esc_html__( "Transition speed", "imate" ),
                        "param_name"  => "speed",
                        "value"       => "300",
                        "min"         => "100",
                        "max"         => "10000",
                        "step"        => "100",
                        "suffix"      => "ms",
                        "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"        => "switch",
                        "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                        "param_name"  => "autoplay",
                        "value"       => "on",
                        "options"     => array(
                            "on" => array(
                                "label" => esc_html__( "Enable Autoplay", "imate" ),
                                "on"    => "Yes",
                                "off"   => "No",
                            ),
                        ),
                        "default_set" => true,
                        "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"       => "number",
                        "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                        "param_name" => "autoplay_speed",
                        "value"      => "5000",
                        "min"        => "100",
                        "max"        => "10000",
                        "step"       => "10",
                        "suffix"     => "ms",
                        "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"        => "switch",
                        "heading"     => esc_html__( "Navigation Arrows", "imate" ),
                        "param_name"  => "arrows",
                        "value"       => "on",
                        "options"     => array(
                            "on" => array(
                                "on"    => "On",
                                "off"   => "Off",
                            ),
                        ),
                        "default_set" => true,
                        "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"       => "colorpicker",
                        "heading"    => esc_html__( "Arrows Color", "imate" ),
                        "param_name" => "arrows_color",
                        "dependency" => Array( "element" => "arrows", "value" => array( "on" ) ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"       => "switch",
                        "heading"    => esc_html__( "Pause on hover", "imate" ),
                        "param_name" => "pauseohover",
                        "value"      => "on",
                        "options"    => array(
                            "on" => array(
                                "label" => esc_html__( "Pause the slider on hover", "imate" ),
                                "on"    => "Yes",
                                "off"   => "No",
                            ),
                        ),
                        "dependency" => Array("element" => "autoplay", "value" => "on" ),
                        "group"       => esc_html__( "Carousel Settings", "imate" ),
                    ),
                    array(
                        "type"        => "number",
                        "heading"     => esc_html__( "Count items", "imate" ),
                        "param_name"  => "count_items",
                        "value"       => '9',
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Colums", "imate" ),
                        "param_name"  => "cols",
                        "value"      => array(
                            esc_html__( "Col 1", "imate" ) => "1",
                            esc_html__( "Col 2", "imate" ) => "2",
                            esc_html__( "Col 3", "imate" ) => "3",
                            esc_html__( "Col 4", "imate" ) => "4",
                        ),
                        "std" => '3',
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Products", "imate" ),
                        "param_name"  => "sort_type",
                        "value"      => array(
                            esc_html__("Simple Products", "imate") => "d",
                            esc_html__("Featured Products", "imate") => "fp",
                            esc_html__("Sale Products", "imate") => "sp",
                            esc_html__("New Products", "imate") => "rp",
                            esc_html__("Best-Selling Products", "imate") => "bsp",
                            esc_html__("Top Rated Products", "imate") => "trp",
                        ),
                        "std" => 'd',
                    ),
                    array(
                        "type"        => "switch",
                        "heading"     => esc_html__( "Show categories", "imate" ),
                        "param_name"  => "show_categories",
                        "value"       => "on",
                        "options"     => array(
                            "on" => array(
                                "on"    => esc_html__( "On", "imate" ),
                                "off"   => esc_html__( "Off", "imate" ),
                            ),
                        ),
                        "default_set" => true,
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Category buttons align", "imate" ),
                        "param_name"  => "category_buttons_align",
                        "value"      => array(
                            esc_html__('Left', 'imate') => 'tal',
                            esc_html__('Center', 'imate') => 'tac',
                            esc_html__('Right', 'imate') => 'tar',
                        ),
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Navigation", "imate" ),
                        "param_name"  => "navigation",
                        "value"      => array(
                            esc_html__( "None", "imate" ) => "none",
                            esc_html__( "Pagination", "imate" ) => "pagination",
                            esc_html__( "Load More", "imate" ) => "load_more",
                        ),
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Order by", "imate" ),
                        "param_name"  => "orderby",
                        "value"      => array(
                            esc_html__('Default', 'imate') => 'post__in',
                            esc_html__('Author', 'imate') => 'author',
                            esc_html__('Category', 'imate') => 'category',
                            esc_html__('Date', 'imate') => 'date',
                            esc_html__('ID', 'imate') => 'ID',
                            esc_html__('Title', 'imate') => 'title',
                        ),
                        "group"       => esc_html__( "Sorting", "imate" ),
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Order", "imate" ),
                        "param_name"  => "order",
                        "value"      => array(
                            esc_html__('Ascending order', 'imate') => 'ASC',
                            esc_html__('Descending order', 'imate') => 'DESC',
                        ),
                        "group"       => esc_html__( "Sorting", "imate" ),
                    ),
                    array(
                        "type"        => "dropdown",
                        "heading"     => esc_html__( "Source", "imate" ),
                        "param_name"  => "source",
                        "value"      => array(
                            esc_html__( "---", "imate" ) => "",
                            esc_html__( "Items", "imate" ) => "items",
                            esc_html__( "Categories", "imate" ) => "categories",
                        ),
                        "group"       => esc_html__( "Source", "imate" ),
                    ),
                    array(
                        "type"        => "dropdown_multi",
                        "heading"     => esc_html__( "Items", "imate" ),
                        "param_name"  => "items",
                        "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                        "value"       => PT_Product_Items::get_all_product_items(),
                        "group"       => esc_html__( "Source", "imate" ),
                    ),
                    array(
                        "type"        => "dropdown_multi",
                        "heading"     => esc_html__( "Category", "imate" ),
                        "param_name"  => "categories",
                        "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                        "value"       => PT_Product_Items::get_all_product_category(),
                        "group"       => esc_html__( "Source", "imate" ),
                    ),
                    array(
                        "type" => "animation_style",
                        "heading" => esc_html__( "Animation In", "imate" ),
                        "param_name" => "animation",
                    ),
                ),
            ) );
        }

        private static function product_loop( $query_args, $atts, $loop_name ) {
            global $woocommerce_loop;
            $columns                     = absint( $atts['columns'] );
            $woocommerce_loop['columns'] = $columns;
            $woocommerce_loop['name']    = $loop_name;
            $query_args                  = apply_filters( 'woocommerce_shortcode_products_query', $query_args, $atts, $loop_name );
            $transient_name              = 'wc_loop' . substr( md5( json_encode( $query_args ) . $loop_name ), 28 ) . WC_Cache_Helper::get_transient_version( 'product_query' );
            $products                    = get_transient( $transient_name );
            if ( false === $products || ! is_a( $products, 'WP_Query' ) ) {
                $products = new WP_Query( $query_args );
                set_transient( $transient_name, $products, DAY_IN_SECONDS * 30 );
            }
            woocommerce_reset_loop();
            wp_reset_postdata();
            return $products;
        }

        private static function _maybe_add_category_args( $args, $category, $operator ) {
            if ( ! empty( $category ) ) {
                if ( empty( $args['tax_query'] ) ) {
                    $args['tax_query'] = array();
                }
                $args['tax_query'][] = array(
                    array(
                        'taxonomy' => 'product_cat',
                        'terms'    => array_map( 'sanitize_title', explode( ',', $category ) ),
                        'field'    => 'slug',
                        'operator' => $operator,
                    ),
                );
            }
            return $args;
        }

        public static function featured_products( $atts ) {
            $atts = shortcode_atts( array(
                'per_page' => '12',
                'columns'  => '4',
                'orderby'  => 'date',
                'order'    => 'desc',
                'category' => '',  // Slugs
                'paged' => '1',
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'featured_products' );
            $meta_query  = WC()->query->get_meta_query();
            $tax_query   = WC()->query->get_tax_query();
            $tax_query[] = array(
                'taxonomy' => 'product_visibility',
                'field'    => 'name',
                'terms'    => 'featured',
                'operator' => 'IN',
            );
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'posts_per_page'      => $atts['per_page'],
                'orderby'             => $atts['orderby'],
                'order'               => $atts['order'],
                'paged'               => $atts['paged'],
                'meta_query'          => $meta_query,
                'tax_query'           => $tax_query,
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            return self::product_loop( $query_args, $atts, 'featured_products' );
        }

        public static function recent_products( $atts ) {
            $atts = shortcode_atts( array(
                'per_page' => '12',
                'columns'  => '4',
                'orderby'  => 'date',
                'order'    => 'desc',
                'category' => '',  // Slugs
                'paged' => '1',
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'recent_products' );
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'posts_per_page'      => $atts['per_page'],
                'orderby'             => $atts['orderby'],
                'order'               => $atts['order'],
                'paged'               => $atts['paged'],
                'meta_query'          => WC()->query->get_meta_query(),
                'tax_query'           => WC()->query->get_tax_query(),
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            return self::product_loop( $query_args, $atts, 'recent_products' );
        }

        public static function sale_products( $atts ) {
            $atts = shortcode_atts( array(
                'per_page' => '12',
                'columns'  => '4',
                'orderby'  => 'title',
                'order'    => 'asc',
                'category' => '', // Slugs
                'paged' => '1',
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'sale_products' );
            $query_args = array(
                'posts_per_page' => $atts['per_page'],
                'orderby'        => $atts['orderby'],
                'order'          => $atts['order'],
                'paged'          => $atts['paged'],
                'no_found_rows'  => 1,
                'post_status'    => 'publish',
                'post_type'      => 'product',
                'meta_query'     => WC()->query->get_meta_query(),
                'tax_query'      => WC()->query->get_tax_query(),
                'post__in'       => array_merge( array( 0 ), wc_get_product_ids_on_sale() ),
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            return self::product_loop( $query_args, $atts, 'sale_products' );
        }

        public static function best_selling_products( $atts ) {
            $atts = shortcode_atts( array(
                'per_page' => '12',
                'columns'  => '4',
                'category' => '',  // Slugs
                'paged' => '1',
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'best_selling_products' );
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'posts_per_page'      => $atts['per_page'],
                'paged'               => $atts['paged'],
                'meta_key'            => 'total_sales',
                'orderby'             => 'meta_value_num',
                'meta_query'          => WC()->query->get_meta_query(),
                'tax_query'           => WC()->query->get_tax_query(),
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            return self::product_loop( $query_args, $atts, 'best_selling_products' );
        }

        public static function top_rated_products( $atts ) {
            $atts = shortcode_atts( array(
                'per_page' => '12',
                'columns'  => '4',
                'orderby'  => 'title',
                'order'    => 'asc',
                'paged' => '1',
                'category' => '',  // Slugs
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'top_rated_products' );
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'orderby'             => $atts['orderby'],
                'order'               => $atts['order'],
                'paged'               => $atts['paged'],
                'posts_per_page'      => $atts['per_page'],
                'meta_query'          => WC()->query->get_meta_query(),
                'tax_query'           => WC()->query->get_tax_query(),
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            add_filter( 'posts_clauses', array( __CLASS__, 'order_by_rating_post_clauses' ) );
            $return = self::product_loop( $query_args, $atts, 'top_rated_products' );
            remove_filter( 'posts_clauses', array( __CLASS__, 'order_by_rating_post_clauses' ) );
            return $return;
        }

        public static function products( $atts ) {
            $atts = shortcode_atts( array(
                'columns' => '4',
                'per_page' => '12',
                'paged' => '1',
                'orderby' => 'title',
                'order'   => 'asc',
                'ids'     => '',
                'skus'    => '',
                'category' => '',  // Slugs
                'operator' => 'IN', // Possible values are 'IN', 'NOT IN', 'AND'.
            ), $atts, 'products' );
            $query_args = array(
                'post_type'           => 'product',
                'post_status'         => 'publish',
                'ignore_sticky_posts' => 1,
                'orderby'             => $atts['orderby'],
                'order'               => $atts['order'],
                'paged'               => $atts['paged'],
                'posts_per_page'      => $atts['per_page'],
                'meta_query'          => WC()->query->get_meta_query(),
                'tax_query'           => WC()->query->get_tax_query(),
            );
            $query_args = self::_maybe_add_category_args( $query_args, $atts['category'], $atts['operator'] );
            if ( ! empty( $atts['skus'] ) ) {
                $query_args['meta_query'][] = array(
                    'key'     => '_sku',
                    'value'   => array_map( 'trim', explode( ',', $atts['skus'] ) ),
                    'compare' => 'IN',
                );
            }
            if ( ! empty( $atts['ids'] ) ) {
                $query_args['post__in'] = array_map( 'trim', explode( ',', $atts['ids'] ) );
            }
            return self::product_loop( $query_args, $atts, 'products' );
        }

        public function return_get_template_part() {

           ob_start();
           wc_get_template_part( 'content', 'product' );    
           $content = ob_get_contents();
           ob_end_clean();

           return $content;
        }
         
         
        // Element HTML
        public function pt_product_html( $atts, $content = null ) {
             
            // Params extraction
            extract(
                shortcode_atts(
                    array(
                        'uniq_id' => uniqid(),
                        'count_items' => '9', 
                        'type' => 'grid',
                        'cols' => '3',
                        'show_categories' => 'on',
                        'category_buttons_align' => 'tal',
                        'navigation' => 'none',
                        'orderby' => 'post__in',
                        'order' => 'ASC',
                        'source' => '',
                        'items' => '',
                        'categories' => '',
                        'sort_type' => 'd',
                        'carousel' => 'off',
                        'speed' => '500',
                        'autoplay' => 'on',
                        'autoplay_speed' => '3000',
                        'pauseohover' => 'on',
                        'bg_color' => '',
                        'text_color' => '',
                        'arrows' => 'on',
                        'arrows_color' => '',
                        'animation' => ''
                    ), 
                    $atts
                )
            );

            $wrap_id = 'product-'.$uniq_id;

            if(is_front_page()) {
                $paged = (get_query_var('page')) ? get_query_var('page') : 1;
            } else {
                $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
            }
            if($source = 'items' && $items) {
                $items = $items;
            } else {
                $items = '';
            }

            if($source = 'categories' && $categories) {
                $categories = $categories;
            } else {
                $categories = '';
            }

            $html = '';

            $atts_array = array(
                'per_page' => $count_items,
                'paged' => $paged,
                'columns' => $cols,
                'ids' => $items,
                'category' => $categories,
                'orderby' => $orderby,
                'order' => $order,
            );

            if(empty($items)) {
                switch ($sort_type) {
                    case 'd':
                    $products = PT_Product_Items::products($atts_array);
                    break;
                    case 'fp':
                    $products = PT_Product_Items::featured_products($atts_array);
                    break;
                    case 'sp':
                    $products = PT_Product_Items::sale_products($atts_array);
                    break;
                    case 'bsp':
                    $products = PT_Product_Items::best_selling_products($atts_array);
                    break;
                    case 'trp':
                    $products = PT_Product_Items::top_rated_products($atts_array);
                    break;
                    case 'rp':
                    $products = PT_Product_Items::recent_products($atts_array);
                    break;

                    default:

                    break;
                } 
            } else {
                $products = PT_Product_Items::products($atts_array);
            }

            $max_num_pages = $products->max_num_pages;

            $custom_css = "";

            $animation = $this->getCSSAnimation($animation);

            if(isset($dots_color) && !empty($dots_color)) {
                $custom_css .= '.'.$id.' .owl-dots {
                    border-color: '.$dots_color.';
                    background-color: '.$dots_color.';
                }';
            }

            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );

            switch ($cols) {
                case '1':
                    $mobile_cols = "1";
                    $tablet_cols = "1";
                    $desktop_cols = "1";
                    break;
                case '2':
                    $mobile_cols = "1";
                    $tablet_cols = "2";
                    $desktop_cols = "2";
                    break;
                case '3':
                    $mobile_cols = "1";
                    $tablet_cols = "2";
                    $desktop_cols = "3";
                    break;
                case '4':
                    $mobile_cols = "1";
                    $tablet_cols = "2";
                    $desktop_cols = "4";
                    break;
                
                default:
                    $item_col = "";
                    break;
            }

            $id = uniqid('products-');

            $html .= '<div class="woocommerce '.esc_attr($animation).'">';
                if($carousel != 'on' && $show_categories == "on") {
                    $html .= '<div class="filter-button-group category-buttons '.esc_attr($category_buttons_align).'">';
                        $html .= '<div class="wrap">';
                            $html .= '<button class="active" data-filter="*">'.esc_html__('All', 'imate').'</button>';
                            $args     = array(
                                'hide_empty' => true,
                            );
                            $taxonomy = 'product_cat';
                            $terms     = get_terms( $taxonomy, $args );
                            if(!empty($terms) && !is_wp_error( $terms )) {
                                foreach($terms as $item) { 
                                    $html .= '<button data-filter=".product_cat-'.esc_attr($item->slug).'">'.esc_html($item->name).'</button>';
                                }
                            }
                        $html .= '</div>';
                    $html .= '</div>';
                }
                if($carousel == 'on') {
                    if($autoplay == 'on') {
                        $autoplay = 'true';
                    } else {
                        $autoplay = 'false';
                    }

                    if($arrows == 'on') {
                        $arrows = 'true';
                    } else {
                        $arrows = 'false';
                    }

                    if($pauseohover == 'on') {
                        $pauseohover = 'true';
                    } else {
                        $pauseohover = 'false';
                    }

                    wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
                    wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
                    wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

                    wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
                        jQuery('.".esc_attr($id)."').each(function(){
                            var head_slider = jQuery(this);
                            if(jQuery(this).find('.col-xs-12').length > 1){
                                head_slider.addClass('owl-carousel').owlCarousel({
                                    loop:true,
                                    items:1,
                                    nav: ".esc_js($arrows).",
                                    dots: false,
                                    autoplay: ".esc_js($autoplay).",
                                    autoplayTimeout: ".esc_js($autoplay_speed).",
                                    autoplayHoverPause: ".esc_js($pauseohover).",
                                    smartSpeed: ".esc_js($speed).",
                                    navClass: ['owl-prev material-design-icon-keyboard-left-arrow-button','owl-next material-design-icon-keyboard-right-arrow-button'],
                                    navText: false,
                                    margin: 30,
                                    responsive:{
                                        0:{
                                            nav: false,
                                        },
                                        480:{
                                            
                                        },
                                        768:{
                                            nav: ".esc_js($arrows).",
                                            items: ".esc_js($mobile_cols).",
                                        },
                                        980:{
                                            items: ".esc_js($tablet_cols).",
                                        },
                                        1200:{
                                            items: ".esc_js($desktop_cols).",
                                        },
                                    },
                                });
                            }
                        });
                    });");
                    $html .= '<div class="products '.esc_attr($id).'">';
                } else {
                    $html .= '<div class="products filter-items row '.esc_attr($wrap_id).'">';
                }
                    global $woocommerce_loop;
                    $woocommerce_loop['columns'] = $cols;

                    if ( $products->have_posts() ) {

                        while ( $products->have_posts() ) : $products->the_post();

                        $html .= PT_Product_Items::return_get_template_part();

                        endwhile;

                    }
                    woocommerce_reset_loop();
                    wp_reset_postdata();

                $html .= '</div>';

            $html .= '</div>';

            if($carousel != 'on' && $navigation == "pagination") {
                if (function_exists('imate_wp_corenavi')) {
                    $html .= imate_wp_corenavi($max_num_pages);
                } else {
                    $html .= wp_link_pages();
                };
            }

            if($carousel != 'on' && is_array($products->posts) && $navigation == "load_more" && $max_num_pages > 1) {
                $html .= '<div class="load-button tac"><a href="#" data-wrap=".'.esc_attr($wrap_id).'" data-max="'.esc_attr($max_num_pages).'" data-start-page="'.esc_attr($paged).'" data-next-link="'.esc_url(next_posts($max_num_pages, false)).'" class="button-style2"><span>'.esc_html('Load more', 'imate').'</span></a></div>';
            }

            return $html;

        }
         
    } // End Element Class
     
     
    // Element Class Init
    new PT_Product_Items();
}