<?php

// Element Description: PT Square Background

class PT_Square_Background extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_square_background_mapping' ) );
        add_shortcode( 'pt_square_background', array( $this, 'pt_square_background_html' ) );
    }
     
    // Element Mapping
    public function pt_square_background_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Square Background", "imate"),
            "base" => "pt_square_background",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-square-background",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Offset Top", "imate"),
                    "param_name" => "offset_top",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Offset Left", "imate"),
                    "param_name" => "offset_left",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Offset Right", "imate"),
                    "param_name" => "offset_right",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Offset Bottom", "imate"),
                    "param_name" => "offset_bottom",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Width", "imate"),
                    "param_name" => "width",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Height", "imate"),
                    "param_name" => "height",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Dots color", "imate"),
                    "param_name" => "dots_color",
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_square_background_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'offset_top' => '',
                    'offset_left' => '',
                    'offset_right' => '',
                    'offset_bottom' => '',
                    'width' => '',
                    'height' => '',
                    'dots_color' => '',
                    'animation' => '',                 
                ), 
                $atts
            )
        );

        $custom_css = '';
        $item_css = $id = uniqid('square-bg-');

        if(!empty($animation)) {
            $item_css .= ' '.$this->getCSSAnimation($animation);
        }

        $custom_css .= '.'.$id.' {';
            if(!empty($offset_top)) {
                $custom_css .= 'top: '.$offset_top.';';
            }
            if(!empty($offset_left)) {
                $custom_css .= 'left: '.$offset_left.';';
            }
            if(!empty($offset_right)) {
                $custom_css .= 'right: '.$offset_right.';';
            }
            if(!empty($offset_bottom)) {
                $custom_css .= 'bottom: '.$offset_bottom.';';
            }
            if(!empty($width)) {
                $custom_css .= 'width: '.$width.';';
            }
            if(!empty($height)) {
                $custom_css .= 'height: '.$height.';';
            }
        $custom_css .= '}';

        if(!empty($dots_color)) {
            $custom_css .= '.'.$id.' { 
                background-image: -webkit-repeating-linear-gradient(to bottom, transparent, transparent 3px, #f7f7f7 3px, #f7f7f7 30px),
    -webkit-repeating-linear-gradient(to right, '.$dots_color.', '.$dots_color.' 3px, #28487d00 3px, #28487d00 30px);
                background-image: -moz-repeating-linear-gradient(to bottom, transparent, transparent 3px, #f7f7f7 3px, #f7f7f7 30px),
    -moz-repeating-linear-gradient(to right, '.$dots_color.', '.$dots_color.' 3px, #28487d00 3px, #28487d00 30px);
                background-image: -ms-repeating-linear-gradient(to bottom, transparent, transparent 3px, #f7f7f7 3px, #f7f7f7 30px),
    -ms-repeating-linear-gradient(to right, '.$dots_color.', '.$dots_color.' 3px, #28487d00 3px, #28487d00 30px);
                background-image: repeating-linear-gradient(to bottom, transparent, transparent 3px, #f7f7f7 3px, #f7f7f7 30px),
    repeating-linear-gradient(to right, '.$dots_color.', '.$dots_color.' 3px, #28487d00 3px, #28487d00 30px);
            }';
        }

        if(!empty($custom_css)) {
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }
        
        ob_start();
        ?>
            <div class="square-bg-block <?php echo esc_attr($item_css) ?>"></div>
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
// Element Class Init
new PT_Square_Background();