<?php

// Element Description: PT Timer

class PT_Timer extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_timer_mapping' ) );
        add_shortcode( 'pt_timer', array( $this, 'pt_timer_html' ) );
    }
     
    // Element Mapping
    public function pt_timer_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Timer", "imate"),
            "base" => "pt_timer",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-timer",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "date-picker",
                    "heading"     => esc_html__( "Date", "imate" ),
                    "param_name"  => "date",
                    "admin_label" => true
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_timer_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'css' => '',
                    'date' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $item_css = $id = uniqid('timer-');

        if(!empty($animation)) {
            $item_css .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $item_css .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        $custom_css = $style_attr = '';

        $year = mysql2date('Y', $date);
        $month = mysql2date('m', $date)-1;
        $day = mysql2date('j', $date);
        $hour = mysql2date('H', $date);
        $minutes = mysql2date('i', $date);

        wp_enqueue_script( 'countdown', get_template_directory_uri() . '/js/jquery.countdown.js' );
        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            /*------------------------------------------------------------------
            [ Coming soon countdown ]
            */

            var ts = new Date(".esc_js($year).", ".esc_js($month).", ".esc_js($day).", ".esc_js($hour).", ".esc_js($minutes).");

            if(jQuery('.".esc_js($id)."').length > 0){
                var degree = 7;
                jQuery('.".esc_js($id)."').countdown({
                    timestamp   : ts,
                    days_h      : 'days',
                    hours_h     : 'hour',
                    minutes_h   : 'minutes',
                    seconds_h   : 'second',
                });
            }
        });");

        ob_start();
        ?>

        <div class="timer-area <?php echo esc_attr($item_css) ?>" id="countdown"></div>
    
        <?php
        return ob_get_clean();
         
    }

    
     
} // End Element Class
 
 
// Element Class Init
new PT_Timer();